@@ -61,6 +61,8 @@ import MMA.tempo
 import MMA.tweaks
 import MMA.options
 import MMA.rpitch
+import MMA.regplug
+import MMA.after
 
 from MMA.timesig import timeSig
 from MMA.parseCL import parseChordLine
@@ -91,6 +93,8 @@ def parseFile(n):
         print("File '%s' closed." % n)
 
 
+    
+                
 def parse(inpath):
     """ Process a mma input file. """
 
@@ -101,8 +105,9 @@ def parse(inpath):
     curline = None
 
     while 1:
+        MMA.after.check()
+        
         curline = inpath.read()
-
         if curline is None:   # eof, exit parser
             break
 
@@ -151,8 +156,6 @@ def parse(inpath):
         if gbl.showExpand and action != 'REPEAT':
             print(l)
 
-        # If the command is in the simple function table, jump & loop.
-
         if action in simpleFuncs:
             simpleFuncs[action](l[1:])
             continue
@@ -1284,6 +1287,7 @@ def trackUnify(name, ln):
 """
 
 simpleFuncs = {'ADJUSTVOLUME': MMA.volume.adjvolume,
+               'AFTER': MMA.after.set,
                'ALLGROOVES': MMA.grooves.allgrooves,
                'ALLTRACKS': allTracks,
                'AUTHOR': MMA.docs.docAuthor,
@@ -1343,6 +1347,7 @@ simpleFuncs = {'ADJUSTVOLUME': MMA.volume.adjvolume,
                'MSETEND': endmset,
                'NEWSET': macros.newsetvar,
                'PATCH': MMA.patch.patch,
+               'PLUGIN': MMA.regplug.plugin,
                'PRINT': lnPrint,
                'PRINTACTIVE': printActive,
                'PRINTCHORD': MMA.chords.printChord,
